MemUsageNode

Struct MemUsageNode 

pub struct MemUsageNode { /* private fields */ }
A node in a MemUsageTree with children.

Implementations

Source

impl MemUsageNode

pub fn new() -> Self

Create a new empty node.

pub fn add(&mut self, name: impl Into<String>, child: impl Into<MemUsageTree>)

Add a child to this node.

The child’s size will be added to this node’s total size.

pub fn add_named_child(&mut self, tree: NamedMemUsageTree)

pub fn with_named_child(self, tree: NamedMemUsageTree) -> Self

pub fn with_child( self, name: impl Into<String>, child: impl Into<MemUsageTree>, ) -> Self

pub fn size_bytes(&self) -> u64

Get the total size in bytes of this node and all its children.

pub fn children(&self) -> &[NamedMemUsageTree]

Get the children of this node.

pub fn with_total_size_bytes(self, size_bytes: u64) -> MemUsageTree

Set the total size in bytes of this node.

Usually the size is computed automatically when adding children, but this can be used to override it if needed, for instance if we have a more accurate size measurement produced some other way.

pub fn into_tree(self) -> MemUsageTree

Convert this node into a MemUsageTree::Node.